@@ -80,7 +80,9 @@ def invalid_file_format(api_inputs: ApiInputs, schema: pandera.DataFrameSchema,
     try:
         schema.validate(raw_df, lazy=True)
     except pandera.errors.SchemaErrors as err:
-        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/{api_inputs.data_feed_id}/errors?status={process_status}&errorType={error_type}&statusId={api_inputs.data_feed_id}"
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/" \
+              f"{api_inputs.data_feed_id}/errors?status={process_status}&errorType={error_type}&statusId=" \
+              f"{api_inputs.data_feed_id}"
         logger.info("Sending request: POST %s", url)
         logger.error('Schema errors present: %s', err.failure_cases)
 
